@@ -22,12 +22,13 @@ module Diagrams.Parametric
 
   ) where
 
+import           Data.Kind (Type)
 import           Diagrams.Core.V
 import qualified Numeric.Interval.Kaucher as I
 
 -- | Codomain of parametric classes.  This is usually either @(V p)@, for relative
 --   vector results, or @(Point (V p))@, for functions with absolute coordinates.
-type family Codomain p :: * -> *
+type family Codomain p :: Type -> Type
 
 -- | Type class for parametric functions.
 class Parametric p where
